$set 3 #Configmenu

$ #ConfigOptions
# ɼ
$ #FocusModel
# â Ȱȭ 
$ #WindowPlacement
# â ġ
$ #ImageDithering
# ̹ 
$ #OpaqueMove
#  ̵ 
$ #FullMax
#  ִȭ
$ #FocusNew
#  â Ȱȭ
$ #FocusLast
# ۾â  â Ȱȭ
$ #ClickToFocus
# Ŭ Ȱȭ
$ #SloppyFocus
#  Ȱȭ
$ #AutoRaise
# ڵ 
$ #ClickRaise
# Ŭ 
$ #SmartRows
#  âġ ()
$ #SmartCols
#  âġ ()
$ #Cascade
# ܽ âġ
$ #LeftRight
# ʿ 
$ #RightLeft
# ʿ 
$ #TopBottom
#  Ʒ
$ #BottomTop
# Ʒ 
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
